@@ -10,9 +10,12 @@ setMethod("param", "Distribution", function(object) object@param)
 setMethod("r", "Distribution", function(object) object@r)
 setMethod("d", "Distribution", function(object) object@d)
 setMethod("p", "Distribution", function(object) object@p)
+setMethod("p.r", "Distribution", function(object) object@p)
 setMethod("q", "Distribution", 
            function(save = "default", status = 0, runLast = TRUE) save@q)
            ### odd arg-list due to existing function in base package 
+setMethod("q.l", "Distribution", 
+           function(object) object@q)
 
 setMethod("p", "Distribution", function(object) object@p)
 setMethod(".lowerExact", "Distribution", function(object){ 
